@@ -55,7 +55,8 @@ class Singleton(type):
 
     def __call__(cls, *args, **kwargs):
         if cls not in cls._instances:
-            cls._instances[cls] = super(Singleton, cls).__call__(*args, **kwargs)
+            cls._instances[cls] = super(
+                Singleton, cls).__call__(*args, **kwargs)
         return cls._instances[cls]
 
 
@@ -82,12 +83,15 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
     def _getConn(self):
         if stime() - self.__connectedAt >= self.__timeOut or self.__conn == None:
-            if self.UseGAIP :
-                self.__conn = httpclient.HTTPSConnection(ServiceURL_GA_TEST if self.IsTest else ServiceURL_GA_REAL)
-            elif self.UseStaticIP :
-                self.__conn = httpclient.HTTPSConnection(ServiceURL_Static_TEST if self.IsTest else ServiceURL_Static_REAL)
-            else :
-                self.__conn = httpclient.HTTPSConnection(ServiceURL_TEST if self.IsTest else ServiceURL_REAL)
+            if self.UseGAIP:
+                self.__conn = httpclient.HTTPSConnection(
+                    ServiceURL_GA_TEST if self.IsTest else ServiceURL_GA_REAL)
+            elif self.UseStaticIP:
+                self.__conn = httpclient.HTTPSConnection(
+                    ServiceURL_Static_TEST if self.IsTest else ServiceURL_Static_REAL)
+            else:
+                self.__conn = httpclient.HTTPSConnection(
+                    ServiceURL_TEST if self.IsTest else ServiceURL_REAL)
 
             self.__connectedAt = stime()
             return self.__conn
@@ -298,8 +302,6 @@ class PopbillBase(__with_metaclass(Singleton, object)):
                 UserID : 회원 아이디
             return
                 회사정보
-            raise
-                PopbillException
         """
         return self._httpget('/CorpInfo', CorpNum, UserID)
 
@@ -325,14 +327,11 @@ class PopbillBase(__with_metaclass(Singleton, object)):
                 UserID :  회원 아이디
             return
                 처리결과. consist of code and message
-            raise
-                PopbillException
         """
         postData = self._stringtify(ContactInfo)
         return self._httppost('/IDs/New', postData, CorpNum, UserID)
 
     def _getToken(self, CorpNum):
-
         try:
             token = self.__tokenCache[CorpNum]
         except KeyError:
@@ -341,7 +340,8 @@ class PopbillBase(__with_metaclass(Singleton, object)):
         refreshToken = True
 
         if token != None:
-            refreshToken = token.expiration[:-5] < linkhub.getTime(self.UseStaticIP, self.UseLocalTimeYN, self.UseGAIP)
+            refreshToken = token.expiration[:-5] < linkhub.getTime(
+                self.UseStaticIP, self.UseLocalTimeYN, self.UseGAIP)
 
         if refreshToken:
             try:
@@ -363,14 +363,114 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         return token
 
-    def _httpget(self, url, CorpNum=None, UserID=None):
+    def getUseHistory(self, CorpNum, SDate, EDate, Page=None, PerPage=None, Order=None):
+        """ 포인트 사용내역 확인
+            args
+                CorpNum : 회원 사업자번호 사업자번호
+                SDate : 조회 기간의 시작일자
+                EDate : 조회 기간의 종료일자
+                Page : 목록 페이지번호 (기본값 1)
+                PerPage : 페이지당 표시할 목록 개수 (기본값 500, 최대 1000)
+                Order : 거래일자를 기준으로 하는 목록 정렬 방향
+            return 검색 기간의 포인트 사용 기록 반환
+        """
+        url = "/UseHistory"
+        url += "?SDate=" + SDate if SDate != None else ""
+        url += "&EDate=" + EDate if EDate != None else ""
+        url += "&Page=" + str(Page) if Page != None else ""
+        url += "&PerPage=" + str(PerPage) if PerPage != None else ""
+        url += "&Order=" + Order if Order != None else ""
+        response = self._httpget(url, CorpNum)
+        return UseHistoryResult(**response.__dict__)
 
+    def getPaymentHistory(self, CorpNum, SDate, EDate, Page=None, PerPage=None):
+        """포인트 결제내역 확인.
+        args
+            CorpNum : 회원 사업자번호 사업자번호
+            SDate : 조회 기간의 시작일자
+            EDate : 조회 기간의 종료일자
+            Page : 목록 페이지번호 (기본값 1)
+            PerPage : 페이지당 표시할 목록 개수 (기본값 500, 최대 1000)
+        return 검색 기간의 포인트 결제 내역 반환
+        raise
+            PopbillException
+        """
+        url = "/PaymentHistory?CorpNum"
+        url += CorpNum if CorpNum != None else ""
+        url += "&SDate=" + SDate if SDate != None else ""
+        url += "&EDate=" + EDate if EDate != None else ""
+        url += "&Page=" + str(Page) if Page != None else ""
+        url += "&PerPage=" + str(PerPage) if PerPage != None else ""
+
+        response = self._httpget(url, CorpNum)
+        return PaymentHistoryResult(**response.__dict__)
+
+    def getRefundHistory(self, CorpNum, Page=None, PerPage=None):
+        """환불신청 내역 확인.
+        args
+            CorpNum : 회원 사업자번호
+            Page : 목록 페이지번호 (기본값 1)
+            PerPage : 페이지당 표시할 목록 개수 (기본값 500, 최대 1000)
+        return 검색 기간의 환불 신청 내역 반환
+        raise
+            PopbillException
+        """
+        url = "/RefundHistory"
+        url += "?CorpNum=" + CorpNum if CorpNum != None else ""
+        url += "&Page=" + str(Page) if Page != None else ""
+        url += "&PerPage=" + str(PerPage) if PerPage != None else ""
+
+        response = self._httpget(url, CorpNum)
+        return RefundHistoryResult(**response.__dict__)
+
+    def refund(self, CorpNum, RefundForm, UserID=None):
+        """환불 신청.
+        args
+            CorpNum : 회원 사업자번호
+            RefundForm : 환불 정보, Reference RefundForm class
+        return
+        raise
+            PopbillException
+        """
+
+        postData = self._stringtify(RefundForm)
+        response =  self._httppost("/Refund",  postData, CorpNum=CorpNum, UserID=UserID)
+        return Response(**response.__dict__)
+
+    def paymentRequest(self, CorpNum, PaymentForm, UserID=None):
+        """무통장 입금신청.
+        args
+            CorpNum : 회원 사업자번호
+            PaymentForm: 환불 정보, Reference PaymentForm class
+        return Payment
+        raise
+            PopbillException
+        """
+        postData = self._stringtify(PaymentForm)
+        response =  self._httppost("/Payment",  postData, CorpNum=CorpNum, UserID=UserID)
+        return PaymentResponse(**response.__dict__)
+
+    def getSettleResult(self, CorpNum, settleCode, UserID=None):
+        """무통장 입금신청 정보확인.
+        args
+            CorpNum : 회원 사업자번호
+            settleCode : 정산코드
+        return SettleResult
+        raise
+            PopbillException
+        """
+        response = self._httpget("/Payment/" + settleCode, CorpNum=CorpNum, UserID=UserID)
+
+        return PaymentHistory(**response.__dict__)
+
+    def _httpget(self, url, CorpNum=None, UserID=None):
         conn = self._getConn()
 
         headers = {"x-pb-version": APIVersion}
 
         if CorpNum != None:
-            headers["Authorization"] = "Bearer " + self._getToken(CorpNum).session_token
+            headers["Authorization"] = "Bearer " + \
+                self._getToken(CorpNum).session_token
 
         if UserID != None:
             headers["x-pb-userid"] = UserID
@@ -394,7 +494,6 @@ class PopbillBase(__with_metaclass(Singleton, object)):
             return Utils.json2obj(responseString)
 
     def _httppost(self, url, postData, CorpNum=None, UserID=None, ActionOverride=None, contentsType=None):
-
         conn = self._getConn()
 
         headers = {"x-pb-version": APIVersion}
@@ -405,7 +504,8 @@ class PopbillBase(__with_metaclass(Singleton, object)):
             headers["Content-Type"] = "application/json; charset=utf8"
 
         if CorpNum != None:
-            headers["Authorization"] = "Bearer " + self._getToken(CorpNum).session_token
+            headers["Authorization"] = "Bearer " + \
+                self._getToken(CorpNum).session_token
         if UserID != None:
             headers["x-pb-userid"] = UserID
 
@@ -437,11 +537,13 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         headers["Content-Type"] = "application/json; charset=utf8"
 
-        headers["x-pb-message-digest"] = base64.b64encode(sha1(postData).digest()).decode('utf-8')
+        headers["x-pb-message-digest"] = base64.b64encode(
+            sha1(postData).digest()).decode('utf-8')
         headers["x-pb-submit-id"] = SubmitID
 
         if CorpNum != None:
-            headers["Authorization"] = "Bearer " + self._getToken(CorpNum).session_token
+            headers["Authorization"] = "Bearer " + \
+                self._getToken(CorpNum).session_token
         if UserID != None:
             headers["x-pb-userid"] = UserID
 
@@ -467,15 +569,16 @@ class PopbillBase(__with_metaclass(Singleton, object)):
             return Utils.json2obj(responseString)
 
     def _httppost_files(self, url, postData, Files, CorpNum, UserID=None):
-
         conn = self._getConn()
 
         boundary = "--POPBILL_PYTHON--"
 
-        headers = {"x-pb-version": APIVersion, "Content-Type": "multipart/form-data; boundary=%s" % boundary}
+        headers = {"x-pb-version": APIVersion,
+                   "Content-Type": "multipart/form-data; boundary=%s" % boundary}
 
         if CorpNum != None:
-            headers["Authorization"] = "Bearer " + self._getToken(CorpNum).session_token
+            headers["Authorization"] = "Bearer " + \
+                self._getToken(CorpNum).session_token
 
         if UserID != None:
             headers["x-pb-userid"] = UserID
@@ -491,7 +594,8 @@ class PopbillBase(__with_metaclass(Singleton, object)):
 
         if postData != None and postData != '':
             buff.write((CRLF + '--' + boundary + CRLF).encode('utf-8'))
-            buff.write(('Content-Disposition: form-data; name="form"' + CRLF).encode('utf-8'))
+            buff.write(
+                ('Content-Disposition: form-data; name="form"' + CRLF).encode('utf-8'))
             buff.write(CRLF.encode('utf-8'))
             buff.write(postData.encode('utf-8'))
 
@@ -500,11 +604,13 @@ class PopbillBase(__with_metaclass(Singleton, object)):
             buff.write(
                 ('Content-Disposition: form-data; name="%s"; filename="%s"' % (f.fieldName, f.fileName) + CRLF).encode(
                     'utf-8'))
-            buff.write(('Content-Type: Application/octet-stream' + CRLF).encode('utf-8'))
+            buff.write(
+                ('Content-Type: Application/octet-stream' + CRLF).encode('utf-8'))
             buff.write(CRLF.encode('utf-8'))
             buff.write(f.fileData)
 
-        buff.write((CRLF + '--' + boundary + '--' + CRLF + CRLF).encode('utf-8'))
+        buff.write((CRLF + '--' + boundary + '--' +
+                   CRLF + CRLF).encode('utf-8'))
 
         multiparted = buff.getvalue()
 
@@ -543,14 +649,17 @@ class CorpInfo(object):
     def __init__(self, **kwargs):
         self.__dict__ = kwargs
 
+
 class BizCheckInfo(object):
     def __init__(self, **kwargs):
         self.__dict__ = kwargs
 
+
 class File(object):
     def __init__(self, **kwargs):
         self.__dict__ = kwargs
 
+
 class PopbillException(Exception):
     def __init__(self, code, message):
         self.code = code
@@ -570,11 +679,59 @@ class JsonObject(object):
         return None
 
 
+class PaymentForm(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+
+class PaymentHistory(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+
+class PaymentHistoryResult(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+        self.__dict__["list"] = [PaymentHistory(**paymentHistory.__dict__) for paymentHistory in kwargs['list']]
+
+
+class PaymentResponse(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+
+class RefundForm(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+
+class RefundHistory(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+
+class RefundHistoryResult(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+        self.__dict__['list'] = [RefundHistory(**refundHistory.__dict__) for refundHistory in kwargs['list']]
+
+
+class UseHistory(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+
+class UseHistoryResult(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+class Response(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
 class PopbillEncoder(JSONEncoder):
     def default(self, o):
         return o.__dict__
 
-
 class Utils:
     @staticmethod
     def _json_object_hook(d):
@@ -582,7 +739,8 @@ class Utils:
 
     @staticmethod
     def json2obj(data):
-        if (type(data) is bytes): data = data.decode('utf-8')
+        if (type(data) is bytes):
+            data = data.decode('utf-8')
         return json.loads(data, object_hook=Utils._json_object_hook)
 
     @staticmethod
@@ -596,3 +754,4 @@ class Utils:
     @staticmethod
     def gzipDecomp(data):
         return zlib.decompress(data, 16 + zlib.MAX_WBITS)
+
