@@ -10,6 +10,7 @@
 # Thanks for your interest.
 
 from .base import PopbillBase, PopbillException
+from datetime import datetime
 
 
 class CashbillService(PopbillBase):
@@ -19,7 +20,7 @@ class CashbillService(PopbillBase):
         """생성자
             args
                 LinkID : 링크허브에서 발급받은 링크아이디(LinkID)
-                SecretKeye 링크허브에서 발급받은 비밀키(SecretKey)
+                SecretKey : 링크허브에서 발급받은 비밀키(SecretKey)
         """
 
         super(self.__class__, self).__init__(LinkID, SecretKey)
@@ -114,9 +115,17 @@ class CashbillService(PopbillBase):
         if EmailSubject != None or EmailSubject != '':
             cashbill.emailSubject = EmailSubject
 
+
+
         postData = self._stringtify(cashbill)
 
-        return self._httppost('/Cashbill', postData, CorpNum, UserID, "ISSUE")
+        response = self._httppost(
+            '/Cashbill', postData, CorpNum, UserID, "ISSUE")
+
+        if response.tradeDT != None:
+            delattr(response, "tradeDT")
+
+        return response
 
     def bulkSubmit(self, CorpNum, SubmitID, cashbillList, UserID=None):
         """ 초대량 발행 접수
@@ -141,7 +150,9 @@ class CashbillService(PopbillBase):
 
         bcb = postData.encode('utf-8')
 
-        return self._httpBulkPost('/Cashbill', bcb, SubmitID , CorpNum, UserID, 'BULKISSUE')
+        response = self._httpBulkPost('/Cashbill', bcb, SubmitID , CorpNum, UserID, 'BULKISSUE')
+
+        return IssueResponse(**response.__dict__)
 
     def getBulkResult(self, CorpNum, SubmitID, UserID=None):
         """ 초대량 접수결과 확인
@@ -157,7 +168,18 @@ class CashbillService(PopbillBase):
         if SubmitID == None or SubmitID == "":
             raise PopbillException(-99999999, "제출아이디가 입력되지 않았습니다.")
 
-        return self._httpget('/Cashbill/BULK/' + SubmitID + '/State', CorpNum, UserID)
+        response = self._httpget(
+            '/Cashbill/BULK/' + SubmitID + '/State', CorpNum, UserID)
+
+        # tradeDT 제거
+        if response.tradeDT != None:
+            delattr(response, "tradeDT")
+
+        # issueDT 추가
+        if response.issueDT == None:
+            now = datetime.now()
+            response.issueDT = now.strftime("%Y%m%d%H%M%S")
+        return response
 
     def register(self, CorpNum, cashbill, UserID=None):
         """ 현금영수증 등록
@@ -399,7 +421,8 @@ class CashbillService(PopbillBase):
         if FranchiseTaxRegID is not None:
             uri += '&FranchiseTaxRegID=' + FranchiseTaxRegID
 
-        return self._httpget(uri, CorpNum, UserID)
+        response = self._httpget(uri, CorpNum, UserID)
+        return CBSearchResult(**response.__dict__)
 
     def getInfo(self, CorpNum, MgtKey):
         """ 상태/요약 정보 조회
@@ -415,7 +438,8 @@ class CashbillService(PopbillBase):
         if MgtKey == None or MgtKey == "":
             raise PopbillException(-99999999, "문서번호가 입력되지 않았습니다.")
 
-        return self._httpget('/Cashbill/' + MgtKey, CorpNum)
+        resposne = self._httpget('/Cashbill/' + MgtKey, CorpNum)
+        return CashbillInfo(**resposne.__dict__)
 
     def getInfos(self, CorpNum, MgtKeyList):
         """ 상태정보 다량 확인, 최대 1000건
@@ -432,7 +456,8 @@ class CashbillService(PopbillBase):
 
         postData = self._stringtify(MgtKeyList)
 
-        return self._httppost('/Cashbill/States', postData, CorpNum)
+        response = self._httppost('/Cashbill/States', postData, CorpNum)
+        return [CashbillInfo(**info.__dict__) for info in response]
 
     def getDetailInfo(self, CorpNum, MgtKey):
         """ 상세정보 조회
@@ -711,3 +736,19 @@ class Cashbill(object):
 class BulkCashbillSubmit(object):
     def __init__(self, **kwargs):
         self.__dict__ = kwargs
+
+class IssueResponse(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+class BulkCashbillIssueResult(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+
+class CashbillInfo(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+class CBSearchResult(object):
+    def __init__(self, **kwargs):
+        self.__dict__ = kwargs
+        self.__dict__['list'] = [CashbillInfo(**info.__dict__) for info in kwargs['list']]
\ No newline at end of file
